/* --------------------------------------------------------------------------
$Id: display_hlhdf.h,v 1.1.1.1 2001/12/14 12:02:39 ahenja Exp $
Program:        

Description:    Used for displaying a complete hlhdf NameList instance.

Author(s):      Anders Henja

Copyright:	Swedish Meteorological and Hydrological Institute, 2000

History:
$Log: display_hlhdf.h,v $
Revision 1.1.1.1  2001/12/14 12:02:39  ahenja
First CVS version of hlhdf

Revision 1.2  2000/03/22 08:30:38  ahenja
Updated with header information.

-----------------------------------------------------------------------------*/
#ifndef DISPLAY_HLHDF_H
#define DISPLAY_HLHDF_H

#include "hlhdf.h"

#define DISPLAY_INDENT 2

/****************************************************
 * Various functions for displaying the different data objects.
 * For displaying the whole file,
 * use: displayGroup on the rootGroup
 ****************************************************/

/* Function:	displayDataBuffer
 * Description:	Displays the content of a databuffer
 * Input:
 *		data	The data
 *		fmt	The format of the data
 *		ndims	The rank
 *		dims	The dimensions
 *		typeSize	The size of one value
 *		offs	The offset for displaying
 *		addNewLine	If a newline should be added after the data has
 *				been printed.
 * Returns:
 * Comment:
 */
void displayDataBuffer(unsigned char* data, const char* fmt, int ndims,
		       hsize_t* dims, size_t typeSize,int offs,int addNewline);

/* Function:	displayCompoundDataset
 * Description:	Displays a compound dataset
 * Input:
 * Returns:
 * Comment:
 */
void displayCompoundDataset(unsigned char* data,NameListType_t* type,int ndims, hsize_t* dims, int offs);

/* Function:	displayCompoundAttributeDef
 * Description:	Displays one attribute definition in a compound type
 * Input:
 * Returns:
 * Comment:
 */
void displayCompoundAttributeDef(CompoundAttributeDef_t* def,int offs);

/* Function:	displayType
 * Description:	Displays a datatype
 * Input:
 * Returns:
 * Comment:
 */
void displayType(NameListType_t* type, int offs);

/* Function:	displayAttribute
 * Description:	displays the contents of an attribute
 * Input:
 * Returns:
 * Comment:
 */
void displayAttribute(NameListAttribute_t* attr,int offs);

/* Function:	displayDataset
 * Description:	displays the contents of a dataset
 * Input:
 * Returns:
 * Comment:
 */
void displayDataset(NameListDataset_t* dset, int offs);

/* Function:	displayGroup
 * Description:	Display the contents of a group with
 *		all its belonging objects
 * Input:
 * Returns:
 * Comment:
 */
void displayGroup(NameListGroup_t* grp,int offs);

#endif
