/* --------------------------------------------------------------------------
$Id: pyhlhdf_common.h,v 1.1.1.1 2001/12/14 12:02:38 ahenja Exp $
Program:        

Description:    Common functions for working with python arrays
		and HDF5 files.

Author(s):      Anders Henja

Copyright:	Swedish Meteorological and Hydrological Institute, 2000

History:
$Log: pyhlhdf_common.h,v $
Revision 1.1.1.1  2001/12/14 12:02:38  ahenja
First CVS version of hlhdf

Revision 1.6  2001/11/08 12:30:24  ahenja
*** empty log message ***

Revision 1.5  2000/03/22 08:53:08  ahenja
Updated with spell checking and header information.
	
-----------------------------------------------------------------------------*/
#ifndef PYHLHDF_COMMON_H
#define PYHLHDF_COMMON_H

#include <Python.h>
#include <hlhdf.h>
#include <Numeric/arrayobject.h>

/* Function:	getFloatFromDictionary
 * Description:	Retrives a float from a dictionary, python equivalent would be
 *		val = dict[name]
 * Input:
 *		name	The name of the attribute
 *		val	The assigned float
 *		dict	The Python dictionary
 * Returns:	0 if error, 1 if ok.
 */
int getFloatFromDictionary(char* name, float* val, PyObject* dict);

/* Function:	getDoubleFromDictionary
 * Description:	Retrives a double from a dictionary, python equivalent would be
 *		val = dict[name]
 * Input:
 *		name	The name of the attribute
 *		val	The assigned double
 *		dict	The Python dictionary
 * Returns:	0 if error, 1 if ok.
 */
int getDoubleFromDictionary(char* name, double* val, PyObject* dict);

/* Function:	getIntegerFromDictionary
 * Description:	Retrives a integer from a dictionary, python equivalent would be
 *		val = dict[name]
 * Input:
 *		name	The name of the attribute
 *		val	The assigned double
 *		dict	The Python dictionary
 * Returns:	0 if error, 1 if ok.
 */
int getIntegerFromDictionary(char* name, int* val, PyObject* dict);

/* Function:	getLongFromDictionary/getUnsignedLongFromDictionary
 * Description:	Retrives a long/unsignedlong from a dictionary, python equivalent would be
 *		val = dict[name]
 * Input:
 *		name	The name of the attribute
 *		val	The assigned double
 *		dict	The Python dictionary
 * Returns:	0 if error, 1 if ok.
 */
int getUnsignedLongFromDictionary(char* name, unsigned long* val, PyObject* dict);
int getLongFromDictionary(char* name, long* val, PyObject* dict);

/* Function:	getFloatFromObject
 * Description:	Retrives a float from an object, python equivalent would be
 *		val = dict.name
 * Input:
 *		name	The name of the attribute
 *		val	The assigned float
 *		dict	The Python dictionary
 * Returns:	0 if error, 1 if ok.
 */
int getFloatFromObject(char* name, float* val, PyObject* dict);

/* Function:	getDoubleFromObject
 * Description:	Retrives a double from an object, python equivalent would be
 *		val = dict.name
 * Input:
 *		name	The name of the attribute
 *		val	The assigned double
 *		dict	The Python dictionary
 * Returns:	0 if error, 1 if ok.
 */
int getDoubleFromObject(char* name, double* val, PyObject* dict);

/* Function:	getIntegerFromObject
 * Description:	Retrives a integer from an object, python equivalent would be
 *		val = dict.name
 * Input:
 *		name	The name of the attribute
 *		val	The assigned double
 *		dict	The Python dictionary
 * Returns:	0 if error, 1 if ok.
 */
int getIntegerFromObject(char* name, int* val, PyObject* dict);

/* Function:	getLongFromObject/getUnsignedLongFromObject
 * Description:	Retrives a long/unsigned long from an object, python equivalent would be
 *		val = dict.name
 * Input:
 *		name	The name of the attribute
 *		val	The assigned double
 *		dict	The Python dictionary
 * Returns:	0 if error, 1 if ok.
 */
int getLongFromObject(char* name, long* val, PyObject* dict);
int getUnsignedLongFromObject(char* name, unsigned long* val, PyObject* dict);

/* Function:	getShortFromObject
 * Description:	Retrives a short from an object, python equivalent would be
 *		val = dict.name
 * Input:
 *		name	The name of the attribute
 *		val	The assigned double
 *		dict	The Python dictionary
 * Returns:	0 if error, 1 if ok.
 */
int getShortFromObject(char* name, short* val, PyObject* dict);

/* Function:	getByteFromObject
 * Description: gets a byte.
 */
int getByteFromObject(char* name, unsigned char* val, PyObject* dict);

/* Function:	getStringFromObject
 * Description:	Retrives a string from a name in an object, python equivalent would be
 *		val = dict.name
 * Input:
 *		name	The name of the attribute
 *		dict	The Python dictionary
 * Returns:	NULL if error, the string otherwise.
 */
char* getStringFromObject(char* name, PyObject* dict);

/* Function:	getIdxIntegerFromTuple
 * Description:	Retrives a integer from a index in a tuple, python equivalent would be
 *		val = tuple[idx]
 * Input:
 *		name	The index of the value
 *		val	The assigned double
 *		dict	The Python dictionary
 * Returns:	0 if error, 1 if ok.
 */
int getIdxIntegerFromTuple(int idx, int* val, PyObject* tuple);

/* Function:	getIdxDoubleFromTuple
 * Description:	Retrives a double from a index in a tuple, python equivalent would be
 *		val = tuple[idx]
 * Input:
 *		name	The index of the value
 *		val	The assigned double
 *		dict	The Python dictionary
 * Returns:	0 if error, 1 if ok.
 */
int getIdxDoubleFromTuple(int idx, double* val, PyObject* tuple);

/* Function:	getStringFromDictionary
 * Description:	Retrives a string from a name in a dictionary, python equivalent would be
 *		val = dict[name]
 * Input:
 *		name	The name of the attribute
 *		dict	The Python dictionary
 * Returns:	NULL if error, the string otherwise.
 */
char* getStringFromDictionary(char* name, PyObject* dict);

/* Function:	setMappingInteger
 * Description:	Sets an integer in a dictionary, the python equivalent would be:
 *		info[keyname]=in_value
 * Input:
 *		info	The Python dictionary
 *		keyname	The name of the attribute
 *		in_value the integer value
 * Returns:	0 if error, 1 if ok.
 */
int setMappingInteger(PyObject* info, char* keyname, int in_value);

/* Function:	setMappingDouble
 * Description:	Sets a double in a dictionary, the python equivalent would be:
 *		info[keyname]=in_value
 * Input:
 *		info	The Python dictionary
 *		keyname	The name of the attribute
 *		in_value the double value
 * Returns:	0 if error, 1 if ok.
 */
int setMappingDouble(PyObject* info, char* keyname, double in_value);

/* Function:	setMappingFloat
 * Description:	Sets a float in a dictionary, the python equivalent would be:
 *		info[keyname]=in_value
 * Input:
 *		info	The Python dictionary
 *		keyname	The name of the attribute
 *		in_value the float value
 * Returns:	0 if error, 1 if ok.
 */
int setMappingFloat(PyObject* info, char* keyname, float in_value);

/* Function:	setMappingString
 * Description:	Sets a string in a dictionary, the python equivalent would be:
 *		info[keyname]=in_value
 * Input:
 *		info	The Python dictionary
 *		keyname	The name of the attribute
 *		in_value the string
 * Returns:	0 if error, 1 if ok.
 */
int setMappingString(PyObject* info,char* keyname,char* in_string);

/* Function:	setMappingString_Length
 * Description:	Sets a string in a dictionary, the python equivalent would be:
 *		info[keyname]=in_string[0:len]
 * Input:
 *		info	The Python dictionary
 *		keyname	The name of the attribute
 *		in_string the string
 *		len	The number of characters that should be taken from the string
 * Returns:	0 if error, 1 if ok.
 */
int setMappingString_Length(PyObject* info,char* keyname,char* in_string,int len);

/* Function:	setObjectInteger
 * Description:	Sets an integer in a object, the python equivalent would be:
 *		info.keyname=in_value
 * Input:
 *		info	The Python object
 *		keyname	The name of the attribute
 *		in_value the integer value
 * Returns:	0 if error, 1 if ok.
 */
int setObjectInteger(PyObject* info, char* keyname, int in_value);

/* Function:	setObjectLong
 * Description:	Sets a long in a object, the python equivalent would be:
 *		info.keyname=in_value
 * Input:
 *		info	The Python object
 *		keyname	The name of the attribute
 *		in_value the long value
 * Returns:	0 if error, 1 if ok.
 */
int setObjectLong(PyObject* info, char* keyname, long in_value);

/* Function:	setObjectUnsignedLong
 * Description:	Sets an unsigned long in a object, the python equivalent would be:
 *		info.keyname=in_value
 * Input:
 *		info	The Python object
 *		keyname	The name of the attribute
 *		in_value the long value
 * Returns:	0 if error, 1 if ok.
 */
int setObjectUnsignedLong(PyObject* info, char* keyname, unsigned long in_value);

/* Function:	setObjectDouble
 * Description:	Sets a double in a object, the python equivalent would be:
 *		info.keyname=in_value
 * Input:
 *		info	The Python object
 *		keyname	The name of the attribute
 *		in_value the double value
 * Returns:	0 if error, 1 if ok.
 */
int setObjectDouble(PyObject* info, char* keyname, double in_value);

/* Function:	setObjectFloat
 * Description:	Sets a float in an object, the python equivalent would be:
 *		info.keyname=in_value
 * Input:
 *		info	The Python object
 *		keyname	The name of the attribute
 *		in_value the float value
 * Returns:	0 if error, 1 if ok.
 */
int setObjectFloat(PyObject* info, char* keyname, float in_value);

/* Function:	setObjectString
 * Description:	Sets a string in an object, the python equivalent would be:
 *		info.keyname=in_value
 * Input:
 *		info	The Python object
 *		keyname	The name of the attribute
 *		in_value the string
 * Returns:	0 if error, 1 if ok.
 */
int setObjectString(PyObject* info,char* keyname,char* in_string);

/* Function:	setObjectString_Length
 * Description:	Sets a string in an object, the python equivalent would be:
 *		info.keyname=in_string[0:len]
 * Input:
 *		info	The Python object
 *		keyname	The name of the attribute
 *		in_string the string
 *		len	The number of characters that should be taken from the string
 * Returns:	0 if error, 1 if ok.
 */
int setObjectString_Length(PyObject* info,char* keyname,char* in_string,int len);

#ifdef KALLE
/* Function:	whatSizeIsHdfFormat
 * Description:	Calculates the size in bytes that the specified type takes.
 * Input:
 *		format, can be one of 'int','float',... (see hlhdf.h) for
 *		more types.
 * Returns:	-1 if error, otherwise the size in bytes
 */
int whatSizeIsHdfFormat(const char* format);
#endif

/* Function:	translatePyFormatToHlHdf
 * Description: Translates a PyArray type to a hlhdf known
 *		format.
 * Input:
 *		type	The PyArray type
 * Returns:	The hlhdf representation if ok, NULL otherwise.
 */
char* translatePyFormatToHlHdf(char type);

/* Function:	pyarraytypeFromHdfType
 * Description: Translates an hlhdf represented type into
 *		a PyArray known format
 * Input:
 *		format	The hlhdf representation
 * Returns:	The PyArray type if ok, -1 otherwise
 */
int pyarraytypeFromHdfType(const char* format);

/* Function:	new1d_ArrayObject
 * Description: Creates a new 1-dimensional PyArrayObject 
 * Input:
 *		nl	The dimension
 *		format	The hlhdf representation of the array to be
 *			created.
 * Returns:	The PyArray if ok, NULL otherwise
 */
PyArrayObject* new1d_ArrayObject(int nl, \
				 const char* format);

/* Function:	new2d_ArrayObject
 * Description: Creates a new 2-dimensional PyArrayObject 
 * Input:
 *		xsize	The x-dimension
 *		ysize	The y-dimension
 *		format	The hlhdf representation of the array to be
 *			created.
 * Returns:	The PyArray if ok, NULL otherwise
 */
PyArrayObject* new2d_ArrayObject(int xsize,int ysize, \
				 const char* format);

#endif
