/* --------------------------------------------------------------------------
$Id: read_vhlhdf.h,v 1.1.1.1 2001/12/14 12:02:41 ahenja Exp $
Program:        

Description:    Used for reading an HDF5 file and building a node tree
		with the HighLevel protocol.

Author(s):      Anders Henja

Copyright:	Swedish Meteorological and Hydrological Institute, 2000

History:
$Log: read_vhlhdf.h,v $
Revision 1.1.1.1  2001/12/14 12:02:41  ahenja
First CVS version of hlhdf

Revision 1.5  2001/12/07 13:20:32  ahenja
Updated with possibilities to read and write references.

Revision 1.4  2000/03/22 08:38:19  ahenja
Updated with spell checking and header information.

-----------------------------------------------------------------------------*/
#ifndef READ_HL_H
#define READ_HL_H
#include "vhlhdf.h"

/* Function: readHL_NodeListFrom
 * Description: Reads an HDF5 file with name filename from the
 *		group fromPath and downwards.
 * Returns: The nodelist from 'fromPath' and downwards if everythin
 *	    was ok, otherwise NULL
 */
HL_NodeList* readHL_NodeListFrom(const char* filename, const char* fromPath);

/* Function: readHL_NodeList
 * Description: Reads an HDF5 file with name filename from the
 *		root group ("/") and downwards.
 * Returns: The nodelist from '/' and downwards if everything
 *	    was ok, otherwise NULL
 */
HL_NodeList* readHL_NodeList(const char* filename);

/* Function: selectNode
 * Description: Selects the node named 'name' to be retrived when
 *		fetching data from the nodelist file.
 * Returns: 1 if everything was ok, otherwise 0
 */
int selectNode(HL_NodeList* nodelist, const char* name);

/* Function: selectAllNodes
 * Description: Selects all nodes in the nodelist to be fetched
 * Returns: 1 if everything was ok, otherwise 0
 */
int selectAllNodes(HL_NodeList* nodelist);

/* Function: fetchMarkedNodes
 * Description: Fills all nodes (marked as select).
 * Returns: 1 if everything was ok, otherwise 0
 */
int fetchMarkedNodes(HL_NodeList* nodelist);

/* Function: fillAttributeNode
 * Description: Fills one attribute node with data.
 * Returns: 1 if everything was ok, otherwise 0
 */
int fillAttributeNode(hid_t file_id, HL_Node* node);

/* 
 * Function: locateNameForReference
 * Description: Tries to do a name lookup for the
 *		object that has got the reference
 *		specified by ref.
 * Returns: NULL on failure or not found, otherwise a
 *	    allocated string with name.
 */
char* locateNameForReference(hid_t file_id, hobj_ref_t* ref);

/* Function: fillReferenceNode
 * Description: Fills one reference node with data.
 * Returns: 1 if everything was ok, otherwise 0
 */
int fillReferenceNode(hid_t file_id, HL_Node* node);

/* Function: fillDatasetNode
 * Description: Fills one dataset node with data.
 * Returns: 1 if everything was ok, otherwise 0
 */
int fillDatasetNode(hid_t file_id, HL_Node* node);

/* Function: fillGroupNode
 * Description: Fills one group node with data.
 * Returns: 1 if everything was ok, otherwise 0
 */
int fillGroupNode(hid_t file_id, HL_Node* node);

/* Function: fillTypeNode
 * Description: Fills one type node with data.
 * Returns: 1 if everything was ok, otherwise 0
 */
int fillTypeNode(hid_t file_id, HL_Node* node);

/* Function: fillNodeWithData
 * Description: Fills one node (will call one of
 *		fillAttributeNode, fillDatasetNode, fillGroupNode
 *		or fillTypeNode all depending on the node type.
 * Returns: 1 if everything was ok, otherwise 0
 */
int fillNodeWithData(hid_t file_id, HL_Node* node);

/* Function: buildTypeDescriptionFromTypeHid
 * Description: Builds the compound type description
 *		from a hid_t typeid.
 *
 * Returns: CompoundTypeDescription if everything was ok, otherwise NULL.
 */
HL_CompoundTypeDescription* buildTypeDescriptionFromTypeHid(hid_t type_id);

#endif
